# © MNELAB developers
#
# License: BSD (3-clause)

from .infowidget import EmptyWidget, InfoWidget
